OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Només visible per a les persones que coincideixen mitjançant la integració del número de telèfon a través de Talk al mòbil",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Només visible per a les persones d'aquesta instància i convidats",
    "Federated" : "Federat",
    "Only synchronize to trusted servers" : "Sincronitza només amb servidors de confiança",
    "Published" : "Publicat",
    "Synchronize to trusted servers and the global and public address book" : "Sincronitza amb servidors de confiança i amb la llibreta d'adreces global i pública",
    "Verify" : "Verifica",
    "Verifying …" : "S'està verificant …",
    "Unable to change password" : "No s'ha pogut canviar la contrasenya",
    "Very weak password" : "Contrasenya molt feble",
    "Weak password" : "Contrasenya feble",
    "So-so password" : "Contrasenya passable",
    "Good password" : "Contrasenya bona",
    "Strong password" : "Contrasenya forta",
    "Groups" : "Grups",
    "Group list is empty" : "La llista de grups està buida",
    "Unable to retrieve the group list" : "No s’ha pogut recuperar la llista de grups",
    "{actor} added you to group {group}" : "{actor} us ha afegit al grup {group}",
    "You added {user} to group {group}" : "Heu afegit {user} al grup {group}",
    "{actor} added {user} to group {group}" : "{actor} ha afegit {user} al grup {group}",
    "An administrator added you to group {group}" : "Un administrador us ha afegit al grup {group}",
    "An administrator added {user} to group {group}" : "Un administrador ha afegit {user} al grup {group}",
    "{actor} removed you from group {group}" : "{actor} us ha tret del grup {group}",
    "You removed {user} from group {group}" : "Heu tret {user} del grup {group}",
    "{actor} removed {user} from group {group}" : "{actor} ha tret {user} del grup {group}",
    "An administrator removed you from group {group}" : "Un administrador us ha tret del grup {group}",
    "An administrator removed {user} from group {group}" : "Un administrador ha tret {user} del grup {group}",
    "Your <strong>group memberships</strong> were modified" : "La vostra <strong>pertinença al grup</strong> ha estat modificada",
    "{actor} changed your password" : "{actor} ha canviat la vostra contrasenya",
    "You changed your password" : "Heu canviat la vostra contrasenya",
    "Your password was reset by an administrator" : "Un administrador ha restablert la vostra contrasenya",
    "Your password was reset" : "La vostra contrasenya ha estat restablerta",
    "{actor} changed your email address" : "{actor} ha canviat la vostra adreça de correu electrònic",
    "You changed your email address" : "Heu canviat la vostra adreça de correu electrònic",
    "Your email address was changed by an administrator" : "Un administrador ha canviat la vostra adreça de correu electrònic",
    "You created an app password for a session named \"{token}\"" : "Heu creat una contrasenya d'aplicació per a una sessió anomenada \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Un administrador ha creat una contrasenya d'aplicació per a una sessió anomenada \"{token}\"",
    "You deleted app password \"{token}\"" : "Heu suprimit \"{token}\" de l’aplicació de contrasenyes",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Heu reanomenat \"{token}\" a \"{newToken} a l'aplicació de contrasenyes",
    "You granted filesystem access to app password \"{token}\"" : "Heu donat accés al sistema de fitxers a l'aplicació de contrasenyes \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Heu tret l'accés al sistema de fitxers a l'aplicació de contrasenyes \"{token}\"",
    "Security" : "Seguretat",
    "You successfully logged in using two-factor authentication (%1$s)" : "Heu iniciat sessió correctament amb l'autenticació de doble factor (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Ha fallat l'inici de sessió mitjançant l'autenticació de doble factor (%1$s)",
    "Remote wipe was started on %1$s" : "S'ha engegat la neteja remota a %1$s",
    "Remote wipe has finished on %1$s" : "Ha finalitzat la neteja remota a %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "S'ha modificat la vostra <strong>contrasenya</strong> o <strong>correu electrònic</strong>",
    "Settings" : "Paràmetres",
    "Could not remove app." : "No s'ha pogut suprimir l'aplicació.",
    "Could not update app." : "No s'ha pogut actualitzar l'aplicació.",
    "Wrong password" : "Contrasenya incorrecta",
    "Unable to change personal password" : "No s'ha pogut canviar la contrasenya personal",
    "Saved" : "S'ha desat",
    "Unable to change password. Password too long." : "No s'ha pogut canviar la contrasenya. És massa llarga.",
    "Authentication error" : "Error d'autenticació",
    "Wrong admin recovery password. Please check the password and try again." : "La contrasenya d'administrador de recuperació és incorrecta. Si us plau, comproveu-la i torneu-ho a provar.",
    "Administrator documentation" : "Documentació d'administrador",
    "User documentation" : "Documentació per a usuaris",
    "Nextcloud help overview" : "Informació general d'ajuda de Nextcloud",
    "Invalid SMTP password." : "Contrasenya SMTP no vàlida.",
    "Email setting test" : "Prova de paràmetres del correu electrònic",
    "Well done, %s!" : "Ben fet, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si heu rebut aquest correu electrònic, sembla que la configuració del correu electrònic és correcta.",
    "Email could not be sent. Check your mail server log" : "No s'ha pogut enviar el correu electrònic. Comproveu el registre del servidor de correu",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Hi ha hagut un problema mentre s'enviava el correu electrònic. Reviseu els paràmetres. (Error: %s)",
    "Invalid account" : "Compte invàlid",
    "Invalid mail address" : "Adreça de correu electrònic no vàlida",
    "Settings saved" : "S'han desat els paràmetres",
    "Unable to change full name" : "No s'ha pogut canviar el nom complet",
    "Unable to change email address" : "No s'ha pogut canviar l'adreça electrònica",
    "Unable to set invalid phone number" : "No es pot establir un número de telèfon no vàlid",
    "Unable to set invalid website" : "No es pot establir un lloc web no vàlid",
    "Some account data was invalid" : "Algunes dades del compte no eren vàlides",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Per tal de verificar el vostre compte de Twitter, publiqueu el següent tweet a Twitter (assegureu-vos de publicar-lo sense cap salt de línia):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Per tal de verificar el vostre lloc web, emmagatzemeu el següent contingut a l’arrel web a '.well-known/CloudIdVerificationCode.txt' (assegureu-vos que el text complet és en una línia):",
    "%1$s changed your password on %2$s." : "%1$s ha canviat la vostra contrasenya a %2$s.",
    "Your password on %s was changed." : "La vostra contrasenya a %s ha canviat.",
    "Your password on %s was reset by an administrator." : "La vostra contrasenya a %s ha estat restablerta per un administrador.",
    "Your password on %s was reset." : "La vostra contrasenya a %s ha estat restablerta.",
    "Password for %1$s changed on %2$s" : "Contrasenya per %1$s canviada a %2$s",
    "Password changed for %s" : "Contrasenya canviada per %s",
    "If you did not request this, please contact an administrator." : "Si no ho heu sol·licitat, poseu-vos en contacte amb un administrador.",
    "Your email address on %s was changed." : "La vostra adreça de correu electrònic a %s ha canviat.",
    "Your email address on %s was changed by an administrator." : "La vostra adreça de correu electrònic a %s ha estat canviada per un administrador.",
    "Email address for %1$s changed on %2$s" : "Adreça de correu electrònic per %1$s canviada a %2$s",
    "Email address changed for %s" : "Adreça de correu electrònic canviada per %s",
    "The new email address is %s" : "La nova adreça de correu electrònic és %s",
    "Your %s account was created" : "S'ha creat el vostre compte %s",
    "Welcome aboard" : "Us donem la benvinguda",
    "Welcome aboard %s" : "Us donem la benvinguda, %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Benvingut al compte %s, podeu afegir, protegir i compartir les vostres dades.",
    "Set your password" : "Establiu la vostra contrasenya",
    "Go to %s" : "Ves a %s",
    "Install Client" : "Instal·la el Client",
    "Apps" : "Aplicacions",
    "Personal" : "Personal",
    "Administration" : "Administració",
    "Users" : "Usuaris",
    "Additional settings" : "Paràmetres addicionals",
    "Artificial Intelligence" : "Intel·ligència artificial",
    "Administration privileges" : "Privilegis d'administració",
    "Groupware" : "Treball en grup",
    "Overview" : "Resum",
    "Basic settings" : "Paràmetres bàsics",
    "Sharing" : "Compartició",
    "Availability" : "Disponibilitat",
    "Calendar" : "Calendari",
    "Personal info" : "Informació personal",
    "Mobile & desktop" : "Mòbil i escriptori",
    "Email server" : "Servidor de correu electrònic",
    "Security & setup warnings" : "Avisos de seguretat i configuració",
    "Background jobs" : "Tasques de fons",
    "Unlimited" : "Il·limitat",
    "Verifying" : "S'està verificant",
    "Brute-force Throttle" : "Limitació de força bruta",
    "Your remote address could not be determined." : "No s'ha pogut determinar la teva adreça remota.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "La vostra adreça remota s'ha identificat com a \"%s\" i en aquests moments s'està limitant per força bruta, cosa que ralenteix el rendiment de diverses sol·licituds. Si l'adreça remota no és la vostra, això pot ser una indicació que un servidor intermediari no està configurat correctament.",
    "Your remote address \"%s\" is not brute-force throttled." : "La vostra adreça remota \"%s\" no està limitada per força bruta.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "És probable que la carpeta de dades i els fitxers siguin accessibles des d'Internet. El fitxer .htaccess no funciona. És molt recomanable que configureu el servidor web de manera que la carpeta de dades deixi de ser accessible o que desplaceu la carpeta de dades fora de l'arrel de documents del servidor web.",
    "Database missing columns" : "Falten columnes a la base de dades",
    "Missing optional column \"%s\" in table \"%s\"." : "Falta la columna opcional \"%s\" a la taula \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Falten algunes columnes opcionals en la base de dades. Com que afegir columnes a taules grans pot tardar una estona i són opcionals, no s'han afegit automàticament. Podeu executar «occ db:add-missing-columns» per a afegir les columnes que falten manualment amb la instància en funcionament. Després d'afegir les columnes, és possible que millori el temps de resposta o la usabilitat d'algunes característiques.",
    "Database missing indices" : "Falten índexs a la base de dades",
    "Database missing primary keys" : "Falten les claus primàries a la base de dades",
    "Missing primary key on table \"%s\"." : "Falta la clau primària a la taula \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Falten algunes claus principals en la base de dades. Com que afegir les claus principals a taules grans pot tardar una estona, no s'han afegit automàticament. Podeu executar «occ db:add-missing-primary-keys» per a afegir les claus principals que falten manualment amb la instància en funcionament.",
    "Database pending bigint migrations" : "Base de dades pendent de migracions bigint",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Algunes columnes de la base de dades no tenen una conversió a big int. A causa del fet que canviar els tipus de columnes a les taules grans podria trigar un temps, no es van canviar automàticament. Si executeu \"occ db:convert-filecache-bigint\", aquests canvis pendents es podrien aplicar manualment. Aquesta operació s'ha de fer mentre la instància està fora de línia.",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Aquesta instància s'està executant en mode de depuració. Habiliteu-ho només per a desenvolupament local i no en entorns de producció.",
    "Default phone region" : "Regió del telèfon per defecte",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "La vostra instal·lació no té definida cap regió de telèfon per defecte. Això és necessari per validar els números de telèfon als paràmetres del perfil sense un codi de país. Per permetre números sense codi de país, afegiu \"default_phone_region\" amb el codi ISO 3166-1 respectiu de la regió al vostre fitxer de configuració.",
    "Email test" : "Prova de correu electrònic",
    "Email test was successfully sent" : "La prova de correu electrònic s'ha enviat correctament",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Encara no heu establert ni verificat la configuració del vostre servidor de correu electrònic. Si us plau, aneu a \"Paràmetres bàsics\" per configurar-los. A continuació, utilitzeu el botó \"Envia un correu electrònic\" a sota del formulari per verificar els paràmetres.",
    "File locking" : "Bloqueig de fitxers",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "El bloqueig de fitxers transaccionals està inhabilitat, això pot provocar problemes amb les condicions de carrera. Habiliteu \"filelocking.enabled\" a config.php per evitar aquests problemes.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "La base de dades s'utilitza per al bloqueig de fitxers transaccionals. Per millorar el rendiment, configureu memcache, si està disponible.",
    "Forwarded for headers" : "Reenviat per a capçaleres",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "El vostra paràmetre de \"trusted_proxies\" no està correctament configurat, hauria de ser un vector.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configuració de la capçalera del servidor intermediari invers és incorrecta. Aquest és un problema de seguretat i pot permetre que un atacant falsi la seva adreça IP com a visible a Nextcloud.",
    "Your IP address was resolved as %s" : "La vostra adreça IP s'ha resolt com a %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configuració de la capçalera del servidor intermediari invers és incorrecta o esteu accedint a Nextcloud des d'un servidor intermediari de confiança. Si no és així, es tracta d'un problema de seguretat i pot permetre que un atacant falsi la seva adreça IP com a visible per a Nextcloud.",
    "Internet connectivity" : "Connectivitat d'Internet",
    "Internet connectivity is disabled in configuration file." : "La connectivitat a Internet està desactivada al fitxer de configuració.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Aquest servidor no té una connexió a Internet operativa: no es pot accedir a diversos punts de connexió. Això significa que no funcionaran algunes de les característiques, com el muntatge d'emmagatzematge extern, les notificacions sobre les actualitzacions o la instal·lació d'aplicacions de tercers. És possible que no funcionin tampoc l'accés a fitxers remots ni l'enviament de correus electrònics de notificació. Establiu una connexió d'aquest servidor a Internet per a gaudir de totes les característiques.",
    "Old server-side-encryption" : "Antic xifratge en el servidor",
    "Disabled" : "Inhabilitat",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "L'antic format de xifratge del servidor està habilitat. Recomanem desactivar-ho.",
    "Maintenance window start" : "Inici de la finestra de manteniment",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "El servidor no té configurada l'hora d'inici de la finestra de manteniment. Això significa que també s'executaran treballs de fons diaris intensius en recursos durant el temps d'ús principal. Es recomana configurar-lo en un moment de baix ús, de manera que els usuaris es vegin menys afectats per la càrrega provocada per aquestes tasques pesades.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "La finestra de manteniment per executar feines de fons pesades és entre les {start}:00 UTC i les {end}:00 UTC",
    "Memcache" : "Memcache",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "No s'ha configurat cap memòria cau. Per millorar el rendiment, configureu una memcache, si està disponible.",
    "Configured" : "Configurat",
    "PHP default charset" : "Conjunt de caràcters per defecte de PHP",
    "PHP configuration option \"default_charset\" should be UTF-8" : "L'opció de configuració de PHP \"default_charset\" hauria de ser UTF-8",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La funció «set_time_limit» del PHP no està disponible. Això pot fer que els scripts s'aturin durant l'execució i interrompin la instal·lació. Us recomanem habilitar aquesta funció.",
    "Freetype" : "Tipus lliure",
    "Supported" : "Compatible",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "La vostra versió de PHP no és compatible amb FreeType, per la qual cosa és possible que les imatges de perfil i la interfície de paràmetres no funcionin correctament.",
    "PHP getenv" : "PHP getenv",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Sembla que el PHP no s'ha configurat correctament per a obtenir les variables d'entorn del sistema. La prova amb getenv(\"PATH\") només retorna una resposta buida.",
    "PHP memory limit" : "Límit de memòria de PHP",
    "The PHP memory limit is below the recommended value of %s." : "El límit de memòria PHP està per sota del valor recomanat de %s.",
    "PHP modules" : "Mòduls PHP",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "En aquesta instància li falten alguns mòduls PHP necessaris. És necessari per instal·lar-los: %s.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "El mòdul OPcache de PHP no està carregat. Per a un millor rendiment, es recomana carregar-lo a la instal·lació PHP.",
    "PHP version" : "Versió de PHP",
    "You are currently running PHP %s." : "Actualment esteu executant PHP %s.",
    "PHP \"output_buffering\" option" : "Opció \"output_buffering\" de PHP",
    "PHP configuration option \"output_buffering\" must be disabled" : "L'opció de configuració de PHP \"output_buffering\" ha d'estar desactivada",
    "Random generator" : "Generador aleatori",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "PHP no ha trobat cap font adequada per a l'atzar, que es desaconsella molt per raons de seguretat.",
    "Secure" : "Segura",
    "Configuration file access rights" : "Drets d'accés al fitxer de configuració",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "S'ha habilitat la configuració de només lectura. Això evita establir alguns paràmetres mitjançant la interfície web. A més, a cada actualització cal habilitar l'escriptura del fitxer manualment.",
    "Nextcloud configuration file is writable" : "El fitxer de configuració de Nextcloud es pot escriure",
    "Database version" : "Versió de la base de dades",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend. This is particularly recommended when using the desktop client for file synchronisation. To migrate to another database use the command line tool: \"occ db:convert-type\"." : "Actualment s'utilitza SQLite com a base de dades de fons. Per a instal·lacions més grans, recomanem que canvieu a un backend de base de dades diferent. Això es recomana especialment quan s'utilitza el client d'escriptori per a la sincronització de fitxers. Per migrar a una altra base de dades, utilitzeu l'eina de línia d'ordres: \"occ db:convert-type\".",
    "Unknown database platform" : "Plataforma de base de dades desconeguda",
    "Architecture" : "Arquitectura",
    "64-bit" : "64-bit",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Sembla que esteu executant una versió PHP de 32 bits. Nextcloud necessita 64 bits per funcionar bé. Si us plau, actualitzeu el vostre sistema operatiu i PHP a 64 bits!",
    "Database transaction isolation level" : "Nivell d'aïllament de transaccions de la base de dades",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "La base de dades no s'executa amb el nivell d'aïllament de transaccions «READ COMMITTED». Això pot provocar problemes quan s'executin diverses accions en paral·lel.",
    "Was not able to get transaction isolation level: %s" : "No s'ha pogut obtenir el nivell d'aïllament de la transacció: %s",
    "Profile information" : "Informació del perfil",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Imatge del perfil, nom complet, correu electrònic, número de telèfon, adreça, lloc web, Twitter, organització, rol, titular, biografia i si el vostre perfil està habilitat",
    "Nextcloud settings" : "Paràmetres del Nextcloud",
    "Task:" : "Tasca:",
    "Machine translation" : "Traducció automàtica",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "La traducció automàtica es pot implementar mitjançant diferents aplicacions. Aquí podeu definir la precedència de les aplicacions de traducció automàtica que heu instal·lat en aquest moment.",
    "Image generation" : "Generació d'imatges",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "La generació d'imatges es pot implementar mitjançant diferents aplicacions. Aquí podeu definir quina aplicació s'ha d'utilitzar.",
    "None of your currently installed apps provide image generation functionality" : "Cap de les vostres aplicacions instal·lades actualment ofereix la funcionalitat de generació d'imatges",
    "Text processing" : "Processament de text",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Les tasques de processament de text es poden implementar mitjançant diferents aplicacions. Aquí podeu definir quina aplicació s'ha d'utilitzar per a quina tasca.",
    "Here you can decide which group can access certain sections of the administration settings." : "Aquí podeu decidir quin grup pot accedir a certes seccions dels paràmetres d'administració.",
    "None" : "Cap",
    "Unable to modify setting" : "No es pot modificar el paràmetre",
    "Allow apps to use the Share API" : "Permet que les aplicacions utilitzin l'API de compartir",
    "Allow resharing" : "Permet compartir de nou",
    "Allow sharing with groups" : "Permetre compartir amb grups",
    "Restrict users to only share with users in their groups" : "Restringeix als usuaris a compartir només amb usuaris del seu grup",
    "Allow users to share via link and emails" : "Permet als usuaris compartir mitjançant enllaços i correus electrònics",
    "Allow public uploads" : "Permet càrregues públiques",
    "Always ask for a password" : "Demana sempre una contrasenya",
    "Enforce password protection" : "Força la protecció amb contrasenya",
    "Exclude groups from password requirements" : "Exclou grups dels requisits de contrasenya",
    "Exclude groups from creating link shares" : "Exclou grups de la creació d'enllaços compartits",
    "Groups excluded from sharing" : "Grups exclosos de compartició",
    "Set default expiration date for shares" : "Estableix la data de caducitat per defecte per comparticions",
    "Enforce expiration date" : "Força la data de caducitat",
    "Default expiration time of new shares in days" : "Temps de caducitat per defecte de les noves comparticions en dies",
    "Expire shares after x days" : "Caduca les accions al cap de x dies",
    "Set default expiration date for shares to other servers" : "Estableix la data de caducitat per defecte per a les accions a altres servidors",
    "Enforce expiration date for remote shares" : "Força aplicació de la data de caducitat per a comparticions remotes",
    "Default expiration time of remote shares in days" : "Temps de caducitat per defecte dels recursos compartits remots en dies",
    "Expire remote shares after x days" : "Caduca les comparticions remotes al cap de x dies",
    "Set default expiration date for shares via link or mail" : "Estableix la data de caducitat per defecte per a les comparticions mitjançant enllaç o correu",
    "Default expiration time of shares in days" : "Temps de caducitat per defecte de les comparticions en dies",
    "Privacy settings for sharing" : "Paràmetres de privadesa per compartir",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si la compleció automàtica \"mateix grup\" i \"integració de números de telèfon\" estan habilitats, n'hi ha prou amb una coincidència per mostrar a l'usuari.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permet l'emplenament automàtic en introduir el nom complet o l'adreça de correu electrònic (ignorant la coincidència de l'agenda i estar al mateix grup)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostra el text de descàrrega de responsabilitat a la pàgina de l'enllaç públic de pujada (només es mostra quan la llista de fitxers està oculta).",
    "Disclaimer text" : "Text d'exempció de responsabilitat",
    "This text will be shown on the public link upload page when the file list is hidden." : "Aquest text es mostrarà a la pàgina de pujada d’enllaç públic quan la llista de fitxers estigui amagada.",
    "Default share permissions" : "Permisos de compatició per defecte",
    "Changed disclaimer text" : "S'ha canviat el text de l'exempció de responsabilitat",
    "Deleted disclaimer text" : "S'ha suprimit el text d'exempció de responsabilitat",
    "Could not set disclaimer text" : "No s'ha pogut establir el text d'exempció de responsabilitat",
    "Two-Factor Authentication" : "Autenticació de doble factor",
    "Enforce two-factor authentication" : "Força l'autenticació de doble factor",
    "Limit to groups" : "Limita per grups",
    "Enforcement of two-factor authentication can be set for certain groups only." : "L’obligació d'autenticació de doble factor es pot definir només per a certs grups.",
    "Two-factor authentication is enforced for all members of the following groups." : "L’autenticació de doble factor està obligada per a tots els membres dels següents grups.",
    "Enforced groups" : "Grups forçats",
    "Two-factor authentication is not enforced for members of the following groups." : "L'autenticació de doble factor no està obligada per als membres dels següents grups.",
    "Excluded groups" : "Grups exclosos",
    "Save changes" : "Desa els canvis",
    "Show details for {appName} app" : "Mostra els detalls de l'aplicació {appName}",
    "Update to {update}" : "Actualitza a {update}",
    "Remove" : "Suprimeix",
    "Disable" : "Inhabilita",
    "Featured" : "Destacat",
    "This app is supported via your current Nextcloud subscription." : "Aquesta aplicació és compatible amb la vostra subscripció actual a Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Les aplicacions destacades es desenvolupen per i dins de la comunitat. Ofereixen funcionalitats centrals i estan preparades per ser emprades en producció.",
    "All apps are up-to-date." : "Totes les aplicacions estan actualitzades.",
    "Icon" : "Icona",
    "Name" : "Nom",
    "Version" : "Versió",
    "Level" : "Nivell",
    "Actions" : "Accions",
    "Results from other categories" : "Resultats d'altres categories",
    "No apps found for your version" : "No s'han trobat aplicacions per la vostra versió",
    "Disable all" : "Inhabilita tot",
    "Download and enable all" : "Baixada i activació de tot",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n  aplicació té una actualització disponible","%n aplicacions tenen una actualització disponible"],
    "_Update_::_Update all_" : ["Actualitza","Actualitza-les totes"],
    "Nothing to show" : "Res a mostrar",
    "Loading" : "S'està carregant",
    "Description" : "Descripció",
    "Details" : "Detalls",
    "All" : "Tots",
    "Limit app usage to groups" : "Limita l’ús de l’aplicació als grups",
    "No results" : "No hi ha resultats",
    "Update to {version}" : "Actualitza a {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Aquesta aplicació no té cap versió mínima de Nextcloud assignada. Això serà un error en el futur.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Aquesta aplicació no té cap versió màxima de Nextcloud assignada. Això serà un error en el futur.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Aquesta aplicació no es pot instal·lar perquè les següents dependències no es compleixen:",
    "Author" : "Autor/a",
    "Categories" : "Categories",
    "Resources" : "Recursos",
    "Documentation" : "Documentació",
    "Interact" : "Interactuar",
    "Report a bug" : "Informa d'un error",
    "Request feature" : "Sol·licitud de característica",
    "Ask questions or discuss" : "Fer preguntes o debatre",
    "Rate" : "Puntua",
    "View in store" : "Mostra-ho al magatzem",
    "Visit website" : "Visita el lloc web",
    "Admin documentation" : "Documentació per a administradors",
    "Developer documentation" : "Documentació per a desenvolupadors",
    "Changelog" : "Registre de canvis",
    "Device name" : "Nom del dispositiu",
    "Cancel renaming" : "Cancel·la el canvi de nom",
    "Save new name" : "Desar el nou nom",
    "Marked for remote wipe" : "Marcat per netejar remotament",
    "Device settings" : "Paràmetres del dispositiu",
    "Allow filesystem access" : "Permet l'accés al sistema de fitxers",
    "Rename" : "Canvia el nom",
    "Revoke" : "Revoca",
    "Wipe device" : "Esborra el dispositiu",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Revocar aquest testimoni podria evitar la neteja del dispositiu si encara no ha començat.",
    "Google Chrome for Android" : "Google Chrome per a Android",
    "{productName} iOS app" : "Aplicació iOS de {productName}",
    "{productName} Android app" : "Aplicació Android de {productName}",
    "{productName} Talk for iOS" : "Talk for iOS de {productName}",
    "{productName} Talk for Android" : "Talk for Android de {productName}",
    "Sync client" : "Client de sincronització",
    "This session" : "Aquesta sessió",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device" : "Dispositiu",
    "Last activity" : "Darrera activitat",
    "Devices & sessions" : "Dispositius i sessions",
    "Web, desktop and mobile clients currently logged in to your account." : "Clients Web, d'escriptori i mòbils connectats actualment al vostre compte.",
    "App name" : "Nom de l'aplicació",
    "Create new app password" : "Crea una nova contrasenya d'aplicació",
    "Error while creating device token" : "S'ha produït un error mentre es creava el testimoni del dispositiu",
    "New app password" : "Nova contrasenya de l'aplicació",
    "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Utilitzeu les credencials següents per configurar la vostra aplicació o dispositiu. Per motius de seguretat, aquesta contrasenya només es mostrarà una vegada.",
    "Login" : "Inici de sessió",
    "Password" : "Contrasenya",
    "Show QR code for mobile apps" : "Mostra el codi QR per aplicacions mòbils",
    "App password copied!" : "S'ha copiat la contrasenya de l'aplicació!",
    "Copy app password" : "Copia la contrasenya de l'aplicació",
    "Login name copied!" : "S'ha copiat el nom d'inici de sessió!",
    "Copy login name" : "Copia el nom d'inici de sessió",
    "Could not copy app password. Please copy it manually." : "No s’ha pogut copiar la contrasenya de l’aplicació. Copieu-la manualment.",
    "Could not copy login name. Please copy it manually." : "No s'ha pogut copiar el nom d'inici de sessió. Si us plau, copieu-lo manualment.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Perquè el servidor funcioni correctament, és important configurar els treballs en segon pla correctament. Cron és el paràmetre recomanat. Per a més informació, vegeu la documentació.",
    "Last job execution ran {time}. Something seems wrong." : "L'última execució de la tasca s'ha executat a les {time}. Sembla que hi ha algun problema.",
    "Last job ran {relativeTime}." : "L'última tasca es va executar {relativeTime}.",
    "Background job did not run yet!" : "La tasca en segon pla encara no s'ha executat!",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (recomanat)",
    "Use system cron service to call the cron.php file every 5 minutes." : "Utilitza el servei cron del sistema per cridar el fitxer cron.php cada 5 minuts.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "L'extensió PHP POSIX és necessària. Consulteu la {linkstart}documentació de PHP{linkend} per obtenir més detalls.",
    "Unable to update background job mode" : "No s'ha pogut actualitzar el mode de tasca en segon pla",
    "Profile" : "Perfil",
    "Enable" : "Activa",
    "Unable to update profile default setting" : "No s'ha pogut actualitzar els paràmetres predeterminats del perfil",
    "Server-side encryption" : "Xifratge en el servidor",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "El xifratge en el servidor permet xifrar els fitxers que s'hi carreguen. Això afecta al rendiment, així que activeu-ho només si és necessari.",
    "Enable server-side encryption" : "Activa el xifratge en el servidor",
    "Please read carefully before activating server-side encryption:" : "Llegiu atentament abans d'activar el xifratge del servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Un cop s’activi el xifratge, tots els fitxers carregats al servidor des d'aquest punt cap endavant quedaran xifrats al servidor. Només serà possible desactivar el xifratge posteriorment si el mòdul criptogràfic actiu té aquesta funció, i es compleixen totes les pre-condicions (p. ex. definir una clau de recuperació).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "El xifratge per si mateix no garanteix la seguretat del sistema. Consulteu la documentació per a més informació sobre com funciona l'aplicació de xifratge i els casos d'ús suportats.",
    "Be aware that encryption always increases the file size." : "Tingueu en compte que el xifratge sempre augmenta la mida del fitxer.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Sempre és bó crear còpies de seguretat de les vostres dades amb regularitat, en el cas de xifratge assegureu-vos de desar les claus de xifratge juntament amb les vostres dades a la còpia de seguretat.",
    "This is the final warning: Do you really want to enable encryption?" : "Avís final: Realment voleu activar xifratge?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No s'ha carregat cap mòdul de xifratge, si us plau activeu un mòdul de xifratge al menú d'aplicacions.",
    "Select default encryption module:" : "Seleccioneu el mòdul criptogràfic per defecte:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Heu de migrar les claus de xifratge del xifratge anterior (ownCloud .= 8.0) al nou. Habiliteu el \"Mòdul de xifratge peredeterminat\" i executeu {command}",
    "Unable to update server side encryption config" : "No es pot actualitzar la configuració del xifratge de la banda del servidor",
    "Please confirm the group removal" : "Confirmeu l'eliminació del grup",
    "Cancel" : "Cancel·la",
    "Confirm" : "Confirma",
    "Submit" : "Envia",
    "Rename group" : "Canvia el nom del grup",
    "Remove group" : "Suprimir el grup",
    "Failed to remove group \"{group}\"" : "No s'ha pogut suprimir el grup \"{group}\"",
    "Current password" : "Contrasenya actual",
    "New password" : "Contrasenya nova",
    "Change password" : "Canvia la contrasenya",
    "Your profile picture" : "La vostra imatge de perfil",
    "Upload profile picture" : "Pujar la imatge de perfil",
    "Choose profile picture from Files" : "Trieu la imatge des de Fitxers",
    "Remove profile picture" : "Treu la imatge de perfil",
    "The file must be a PNG or JPG" : "El fitxer ha de ser PNG o JPG",
    "Picture provided by original account" : "Imatge proporcionada pel compte original",
    "Set as profile picture" : "Estableix com a imatge de perfil",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Tingueu en compte que la imatge de perfil pot tardar fins a 24 hores a actualitzar-se  a tot arreu.",
    "Choose your profile picture" : "Trieu la vostra imatge de perfil",
    "Please select a valid png or jpg file" : "Seleccioneu un fitxer png o jpg vàlid",
    "Error setting profile picture" : "Error en establir la imatge de perfil",
    "Error cropping profile picture" : "Error en retallar la imatge de perfil",
    "Error saving profile picture" : "Error en desar la imatge de perfil",
    "Error removing profile picture" : "Error en treure la imatge de perfil",
    "Your biography" : "La vostra biografia",
    "You are a member of the following groups:" : "Sou membre dels grups següents:",
    "You are using <strong>{usage}</strong>" : "Esteu utilitzant <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Esteu utilitzant <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "El vostre nom complet",
    "Primary email for password reset and notifications" : "Adreça de correu electrònic principal per a restablir la contrasenya i per a les notificacions",
    "Email options" : "Opcions de correu electrònic",
    "Remove primary email" : "Treu l'adreça de correu electrònic principal",
    "Delete email" : "Treu l'adreça de correu electrònic",
    "This address is not confirmed" : "Aquesta adreça no està confirmada",
    "Unset as primary email" : "Desactivat com a correu electrònic principal",
    "Set as primary email" : "Estableix com a correu electrònic principal",
    "Additional email address {index}" : "Adreça de correu electrònic addicional {index}",
    "Unable to delete primary email address" : "No es pot suprimir l'adreça de correu electrònic principal",
    "Unable to update primary email address" : "No es pot actualitzar l'adreça de correu electrònic principal",
    "Unable to add additional email address" : "No es pot afegir una adreça de correu electrònic addicional",
    "Unable to update additional email address" : "No es pot actualitzar l'adreça de correu electrònic addicional",
    "Unable to delete additional email address" : "No es pot suprimir l'adreça de correu electrònic addicional",
    "No email address set" : "No s'ha establert cap adreça de correu electrònic",
    "Your handle" : "El teu identificador",
    "Your headline" : "El teu titular",
    "Help translate" : "Ajudeu-nos amb la traducció",
    "Unable to update language" : "No es pot actualitzar la llengua",
    "No language set" : "No s'ha establert cap idioma",
    "Week starts on {firstDayOfWeek}" : "La setmana comença el {firstDayOfWeek}",
    "Unable to update locale" : "No es pot actualitzar la configuració local",
    "No locale set" : "No s'ha establert cap configuració local",
    "Your city" : "La teva ciutat",
    "Your organisation" : "La vostra organització",
    "Your phone number" : "El vostre número de telèfon",
    "Edit your Profile visibility" : "Edició de la visibilitat del vostre perfil",
    "Unable to update profile enabled state" : "No es pot actualitzar l'estat d'habilitació del perfil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "El paràmetre més restrictiu de visibilitat o abast es respecta al vostre perfil. Per exemple, si la visibilitat s'estableix a \"Mostra a tothom\" i l'abast s'estableix a \"Privat\", es respectarà \"Privat\".",
    "Unable to update visibility of {displayId}" : "No es pot actualitzar la visibilitat de {displayId}",
    "Your role" : "El teu rol",
    "Your X (formerly Twitter) handle" : "El vostre identificador X (anteriorment Twitter)",
    "Your website" : "El teu lloc web",
    "No {property} set" : "No hi ha {property} establert",
    "Unable to update {property}" : "No es pot actualitzar {property}",
    "Change scope level of {property}, current scope is {scope}" : "Canvia el nivell d'abast de {property}, l'abast actual és {scope}",
    "Unable to update federation scope of the primary {property}" : "No es pot actualitzar l'àmbit de la federació de la {property} principal",
    "Unable to update federation scope of additional {property}" : "No es pot actualitzar l'àmbit de la federació de {property} addicional",
    "Add additional email" : "Afegeix un correu electrònic addicional",
    "Add" : "Afegeix",
    "Create" : "Crea",
    "Change" : "Canvia",
    "Delete" : "Suprimeix",
    "Reshare" : "Tornar a compartir",
    "Default language" : "Llengua per defecte",
    "Common languages" : "Llengües freqüents",
    "Other languages" : "Altres llengües",
    "Password change is disabled because the master key is disabled" : "El canvi de contrasenya està inhabilitat perquè la clau mestra està desactivada",
    "New account" : "Nou compte",
    "Display name" : "Nom per mostrar",
    "Either password or email is required" : "Es requereix una contrasenya o un correu electrònic",
    "Password (required)" : "Contrasenya (obligatori)",
    "Email (required)" : "Correu electrònic (obligatori)",
    "Email" : "Correu electrònic",
    "Quota" : "Quota",
    "Language" : "Llengua",
    "Set default language" : "Estableix la llengua predeterminada",
    "Manager" : "Gestor",
    "Total rows summary" : "Resum de totes les files",
    "Scroll to load more rows" : "Desplaceu-vos per carregar més files",
    "Avatar" : "Avatar",
    "Group admin for" : "Administrador de grup per",
    "Storage location" : "Ubicació de l'emmagatzematge",
    "Last login" : "Darrer inici de sessió",
    "Account actions" : "Accions del compte",
    "Password or insufficient permissions message" : "Contrasenya o missatge de permisos insuficients",
    "Change display name" : "Canvia el nom de visualització",
    "Set new password" : "Estableix una contrasenya nova",
    "Set new email address" : "Estableix una nova adreça de correu electrònic",
    "Set the language" : "Estableix la llengua",
    "{size} used" : "{size} en ús",
    "Delete account" : "Suprimeix el compte",
    "Resend welcome email" : "Torna a enviar el correu electrònic de benvinguda",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En cas de perdre un dispositiu o sortir de l’organització, es pot esborrar de forma remota les dades del Nextcloud de tots els dispositius associats a {userid}. Només funciona si els dispositius estan connectats a Internet.",
    "Remote wipe of devices" : "Neteja remota de dispositius",
    "Wipe {userid}'s devices" : "Neteja els dispositius de {userid}",
    "Wiped {userid}'s devices" : "S'han esborrat els dispositius de {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Suprimir completament el compte de {userid} inclosos tots els seus fitxers personals, dades d'aplicacions, etc.",
    "Account deletion" : "Supressió del compte",
    "Delete {userid}'s account" : "Suprimir el compte de {userid}",
    "Display name was successfully changed" : "El nom a mostrar s'ha canviat correctament",
    "Password was successfully changed" : "La contrasenya s'ha canviat correctament",
    "Email was successfully changed" : "El correu electrònic s'ha canviat correctament",
    "Welcome mail sent!" : "S'ha enviat el correu electrònic de benvinguda!",
    "Done" : "Fet",
    "Edit" : "Edició",
    "Visibility" : "Visibilitat",
    "Show language" : "Mostra la llengua",
    "Show storage path" : "Mostra el camí del magatzem",
    "Show last login" : "Mostra el darrer inici de sessió",
    "Sorting" : "Ordenació",
    "Send email" : "Envia el correu electrònic",
    "Defaults" : "Valors per defecte",
    "Default quota" : "Quota per defecte",
    "Select default quota" : "Seleccioneu la quota per defecte",
    "Passwordless authentication requires a secure connection." : "L'autenticació sense contrasenya necessita una connexió segura.",
    "Add WebAuthn device" : "Afegeix un dispositiu WebAuthn",
    "Please authorize your WebAuthn device." : "Si us plau, autoritzeu el vostre dispositiu WebAuthn.",
    "Adding your device …" : "S'està afegint el vostre dispositiu …",
    "Server error while trying to complete WebAuthn device registration" : "Error del servidor mentre s'intentava completar el registre del dispositiu WebAuthn",
    "Unnamed device" : "Dispositiu sense nom",
    "Passwordless Authentication" : "Autenticació sense Contrasenya",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configura el teu compte per a l'autenticació sense contrasenya seguint l'estàndard FIDO2.",
    "No devices configured." : "No hi han dispositius configurats.",
    "The following devices are configured for your account:" : "Els següents dispositius estan configurats per al vostre compte:",
    "Your browser does not support WebAuthn." : "El vostre navegador no suporta WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Com a administrador, podeu afinar els ajustaments per compartir fitxers. Si us plau, per més informació llegiu la documentació.",
    "You need to enable the File sharing App." : "Heu d'habilitar l'aplicació per compartir Fitxers.",
    "Admins" : "Administradors",
    "Create group" : "Crear grup",
    "Group name" : "Nom del grup",
    "Please enter a valid group name" : "Introduïu un nom de grup vàlid",
    "Failed to create group" : "No s'ha pogut crear el grup",
    "Sending…" : "S'està enviant…",
    "Email sent" : "S'ha enviat el correu electrònic",
    "Location" : "Ubicació",
    "Profile picture" : "Foto de perfil",
    "About" : "Quant a",
    "Full name" : "Nom complet",
    "Additional email" : "Adreça de correu electrònic addicional",
    "Headline" : "Titular",
    "Organisation" : "Organització",
    "Phone number" : "Número de telèfon",
    "Role" : "Càrrec",
    "X (formerly Twitter)" : "X (abans Twitter)",
    "Fediverse (e.g. Mastodon)" : "Fediverse (p. ex. Mastodon)",
    "Website" : "Lloc web",
    "Profile visibility" : "Visibilitat del perfil",
    "Locale" : "Configuració regional",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No disponible, ja que aquesta propietat és necessària per a les funcions bàsiques, com ara compartir fitxers i invitacions al calendari",
    "Your apps" : "Les vostres aplicacions",
    "Active apps" : "Aplicacions actives",
    "Disabled apps" : "Aplicacions inhabilitades",
    "Updates" : "Actualitzacions",
    "App bundles" : "Paquets d'aplicacions",
    "Featured apps" : "Aplicacions destacades",
    "Supported apps" : "Aplicacions compatibles",
    "Show to everyone" : "Mostra a tothom",
    "Hide" : "Amaga",
    "Download and enable" : "Baixa i activa",
    "Allow untested app" : "Permet l'aplicació no provada",
    "The app will be downloaded from the App Store" : "L'aplicació es baixarà des del Magatzem d'aplicacions",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aquesta aplicació no està marcada com a compatible amb la vostra versió de Nextcloud. Si continueu, encara podreu instal·lar l’aplicació. Tingueu en compte que pot ser que l’aplicació no funcioni correctament.",
    "Never" : "Mai",
    "An error occurred during the request. Unable to proceed." : "S'ha produït un error durant la sol·licitud. No es pot continuar.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'aplicació s'ha habilitat però ha de ser actualitzada. Sereu redirigits a la pàgina d’actualització d'aquí 5 segons.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: aquesta aplicació no es pot habilitar perquè fa que el servidor sigui inestable",
    "Do you really want to wipe your data from this device?" : "Esteu segurs de que voleu netejar les vostres dades d'aquest dispositiu?",
    "Confirm wipe" : "Confirma neteja",
    "Could not delete the app token" : "No s'ha pogut suprimir el testimoni de l'aplicació",
    "Error while wiping the device with the token" : "S'ha produït un error mentre es netejava el dispositiu amb el token",
    "Error while updating device token name" : "S'ha produït un error mentre s'actualitzava el nom del testimoni del dispositiu",
    "Error while updating device token scope" : "S'ha produït un error mentre s'actualitzava l’abast de testimonis del dispositiu",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hi havia massa sol·licituds de la seva xarxa. Reintentar més tard o contactar amb l'administrador si això és un error.",
    "Error" : "Error",
    "Account documentation" : "Documentació del compte",
    "Administration documentation" : "Documentació administrativa",
    "Forum" : "Fòrum",
    "General documentation" : "Documentació general",
    "Legal notice" : "Avís legal",
    "Privacy policy" : "Política de privadesa",
    "None/STARTTLS" : "Cap/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Obre la documentació",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "És important configurar aquest servidor per poder enviar correus electrònics, com ara per poder restablir la contrasenya i notificacions.",
    "Send mode" : "Mode d'enviament",
    "Encryption" : "Xifratge",
    "Sendmail mode" : "Mode sendmail",
    "From address" : "Des de l'adreça",
    "Server address" : "Adreça del servidor",
    "Port" : "Port",
    "Authentication" : "Autenticació",
    "Authentication required" : "Cal autenticació",
    "Credentials" : "Credencials",
    "SMTP Password" : "Contrasenya SMTP",
    "Save" : "Desa",
    "Test and verify email settings" : "Prova i verifica els paràmetres del correu electrònic",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "És important per a la seguretat i el rendiment de la vostra instància que tot estigui configurat correctament. Per ajudar-vos, fem algunes comprovacions automàtiques. Si us plau, consulteu la documentació enllaçada per obtenir més informació.",
    "All checks passed." : "Totes les comprovacions correctes.",
    "There are some errors regarding your setup." : "Hi ha alguns errors pel que fa a la vostra configuració.",
    "There are some warnings regarding your setup." : "Hi ha algunes advertències pel que fa a la vostra configuració.",
    "Checking for system and security issues." : "S'estan comprovant incidències del sistema i de seguretat.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Si us plau reviseu les <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guies d’instal·lació ↗</a>, i comproveu si hi ha errors o advertències en el <a href=\"%2$s\">registre</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Reviseu la seguretat del vostre Nextcloud mitjançant el <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nostre escaneig de seguretat ↗</a>.",
    "Reasons to use Nextcloud in your organization" : "Motius per a utilitzar Nextcloud en la vostra organització",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desenvolupat per la {communityopen}comunitat Nextcloud{linkclose}, el {githubopen}codi font{linkclose} es troba sota la llicència {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Poseu un m’agrada a la nostra pàgina de Facebook",
    "Follow us on Twitter" : "Seguiu-nos a Twitter",
    "Follow us on Mastodon" : "Seguiu-nos a Mastodon",
    "Check out our blog" : "Consulteu el nostre bloc",
    "Subscribe to our newsletter" : "Subscriviu-vos al nostre butlletí",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Aquest llançament de la comunitat de Nextcloud no és compatible i les notificacions instantànies no estan disponibles.",
    "Use a second factor besides your password to increase security for your account." : "Feu servir un segon factor a més de la vostra contrasenya per augmentar la seguretat del vostre compte.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si utilitzeu aplicacions de tercers per a connectar-vos a Nextcloud, assegureu-vos de crear i configurar una contrasenya d'aplicació per a cadascuna abans d'habilitar l'autenticació de segon factor.",
    "No user supplied" : "No heu proporcionat cap usuari",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Si us plau, proporcioneu una contrasenya d'administrador de recuperació; en cas contrari, es perdran totes les dades.",
    "Backend does not support password change, but the user's encryption key was updated." : "El rerefons no admet el canvi de contrasenya, però s'ha actualitzat la clau de xifratge de l'usuari.",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Heu d'establir el correu electrònic d'usuari abans de poder enviar correus de prova. Aneu a %s per fer-ho.",
    "Invalid user" : "Usuari no vàlid",
    "Your username is: %s" : "El vostre nom d'usuari és: %s",
    "Logged in user must be a subadmin" : "L’usuari que ha iniciat la sessió ha de ser un subadministrador",
    "Old user imported certificates" : "Certificats importats d'usuari antic",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Hi ha un treball en segon pla pendent que de comprovar els certificats SSL importats per l'usuari. Comproveu-ho més tard.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hi ha alguns certificats SSL importats per l'usuari que ja no s'utilitzen amb Nextcloud 21. Es poden importar en la línia d'ordres a través de l'ordre «occ security:certificates:import». A continuació se'n mostren els camins dins del directori de dades.",
    "Missing optional index \"%s\" in table \"%s\"." : "Falta l'índex opcional \"%s\" a la taula \"%s\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Falten alguns índexs en la base de dades. Com que afegir índexs a taules grans pot tardar una estona, no s'han afegit automàticament. Si executeu «occ db:add-missing-indices», els índexs que falten es podran afegir manualment amb la instància en funcionament. Un cop afegits els índexs, les consultes en les taules solen ser molt més ràpides.",
    "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "Actualment esteu executant PHP %s. PHP 8.0 ara està obsolet a Nextcloud 27. Nextcloud 28 pot requerir almenys PHP 8.1. Si us plau, actualitzeu a una de les versions de PHP amb suport oficial proporcionades pel Grup PHP tan aviat com sigui possible.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "S'utilitza la versió \"%s\" de MariaDB . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen MariaDB 10.2 o superior.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "S'utilitza la versió \"%s\" de MariaDB . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen MySQL 8.0 o MariaDB 10.2 o superior.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "S'utilitza la versió \"%s\" de PostgreSQL . Nextcloud 21 i les versions superiors no admeten aquesta versió i requereixen PostgreSQL 9.6 o superior.",
    "Speech-To-Text" : "Conversió de parla a text",
    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "La conversió de parla a text es pot implementar per diferents aplicacions. Aquí podeu definir quina aplicació s'ha d'utilitzar.",
    "None of your currently installed apps provide Speech-To-Text functionality" : "Cap de les vostres aplicacions instal·lades actualment ofereix la funció de conversió de parla a text",
    "None of your currently installed apps provide Text processing functionality" : "Cap de les vostres aplicacions instal·lades actualment ofereix la funcionalitat de processament de text",
    "Exclude groups from sharing" : "Excloure grups de compartició",
    "These groups will still be able to receive shares, but not to initiate them." : "Aquests grups encara podran rebre comparticions, però no en podran iniciar.",
    "Allow username autocompletion in share dialog and allow access to the system address book" : "Permet l'emplenament automàtic del nom d'usuari al diàleg de compartició i permet l'accés a la llibreta d'adreces del sistema",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "L’autenticació de doble factor pot ser forçada per a tots els usuaris i grups específics. Si no tenen un proveïdor de doble factor configurat, no podran accedir en el sistema.",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Quan es seleccionen/exclouen grups, es fa servir la lògica següent per determinar si un usuari té 2FA (Autenticació de 2 Factors) forçosa: si no hi ha grups seleccionats, 2FA està habilitat per a tothom, a excepció de membres dels grups exclosos. Si els grups estan seleccionats, 2FA està activada per a tots els membres d'aquests. Si un usuari està tant en un grup seleccionat com exclòs, els seleccionats tenen prioritat i 2FA s'imposa.",
    "{license}-licensed" : "sota la llicència - {license}",
    "Rating: {score}/10" : "Valoració: {score}/10",
    "Username" : "Nom d'usuari",
    "Execute one task with each page loaded. Use case: Single user instance." : "Executeu una tasca amb cada pàgina carregada. Cas d'ús: instància d'un sol usuari.",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php està registrat en un servei webcron per cridar a cron.php cada 5 minuts per HTTP. Cas d'ús: instància molt petita (1-5 usuaris segons l'ús).",
    "The cron.php needs to be executed by the system user \"{user}\"." : "El cron.php l'ha d'executar l'usuari del sistema \"{user}\".",
    "Enable or disable profile by default for new users." : "Habilitar o deshabilitar el perfil per defecte per als usuaris nous.",
    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Esteu a punt de suprimir el grup \"{group}\". Els usuaris NO s'eliminaran.",
    "Additional emails" : "Adreces de correu electrònic addicionals",
    "Enable Profile" : "Habilita el perfil",
    "No users" : "Cap usuari",
    "Loading users …" : "S'estan carregant usuaris …",
    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Llista d'usuaris. Aquesta llista no es presenta completament per motius de rendiment. Els usuaris es mostraran mentre navegueu per la llista.",
    "New user" : "Nou usuari",
    "Groups (required)" : "Grups (obligatori)",
    "Set user groups" : "Establir grups d'usuaris",
    "Administered groups" : "Grups administrats",
    "Set user as admin for …" : "Estableix l'usuari com a administrador de …",
    "Set user quota" : "Estableix la quota d'usuari",
    "Add new user" : "Afegeix un usuari nou",
    "Set user manager" : "Estableix el gestor d'usuaris",
    "Username will be autogenerated" : "El nom d'usuari es generarà automàticament",
    "Username (required)" : "Nom d'usuari (obligatori)",
    "User backend" : "Rerefons d'usuari",
    "User actions" : "Accions de l'usuari",
    "Loading user …" : "S'està carregant l'usuari …",
    "You do not have permissions to see the details of this user" : "No teniu els permisos necessaris per veure els detalls d'aquest usuari",
    "Add user to group" : "Afegeix l'usuari al grup",
    "Set user as admin for" : "Posa l'usuari com a administrador per",
    "Select user quota" : "Selecciona la quota d'usuari",
    "Delete user" : "Suprimeix l'usuari",
    "Wipe all devices" : "Esborra tots els dispositius",
    "Disable user" : "Inhabilita l'usuari",
    "Enable user" : "Habilita l'usuari",
    "Failed to update user manager" : "No s'ha pogut actualitzar el gestor d'usuaris",
    "Toggle user actions menu" : "Commuta el menú d'accions d'usuari",
    "User management settings" : "Paràmetres de gestió d'usuaris",
    "Show user backend" : "Mostra el rerefons d'usuari",
    "Send welcome email to new users" : "Envieu un correu electrònic de benvinguda als nous usuaris",
    "Name your device" : "Anomeneu el vostre dispositiu",
    "Server error while trying to add WebAuthn device" : "Error del servidor mentre s'intentava afegir un dispositiu WebAuthn",
    "by {author}\n{license}" : "{author}\n{license}",
    "User management" : "Gestió d'usuaris",
    "Active users" : "Usuaris actius",
    "Disabled users" : "Usuaris inhabilitats",
    "Creating group …" : "S'està creant un grup …",
    "User group: {group}" : "Grup d'usuaris: {group}",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "No està disponible perquè la federació s'ha inhabilitat per al vostre compte, poseu-vos en contacte amb l'administrador del sistema si teniu cap pregunta",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "No està disponible perquè no es permet la publicació de dades específiques de l'usuari al servidor de cerca, poseu-vos en contacte amb l'administrador del sistema si teniu cap pregunta",
    "Show to logged in users only" : "Mostra només als usuaris connectats",
    "Nextcloud help resources" : "Recursos d'ajuda de Nextcloud",
    "SMTP Username" : "Nom d'usuari SMTP"
},
"nplurals=2; plural=(n != 1);");
